/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.framework.pay.config;

import com.alipay.api.AlipayApiException;
import com.framework.pay.core.PayFactory;
import com.framework.pay.core.handler.alipay.config.AliPayProperties;
import com.framework.pay.core.handler.alipay.config.AlipayClientComponent;
import com.framework.pay.core.toolkit.ApplicationContextHolder;
import org.springframework.boot.autoconfigure.condition.ConditionalOnBean;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.context.annotation.Bean;

/**
 * @Filename: PayAutoConfiguration
 * @Author: zzy
 * @Data:2023/4/28 21:35
 * @Description: 支付自动装配类
 */
public class PayAutoConfiguration {


    /**
     * 支付策略类，可获取实际支付对象
     *
     * @return
     */
    @Bean
    @ConditionalOnMissingBean
    public PayFactory payFactory(){
        return new PayFactory();
    }

    /**
     * 阿里支付client组件
     *
     * @param aliPayProperties
     * @return
     * @throws AlipayApiException
     */
    @Bean
    @ConditionalOnProperty(prefix = AliPayProperties.PREFIX,name = "enabled",havingValue = "true")
    public AlipayClientComponent alipayClientComponent(AliPayProperties aliPayProperties) throws AlipayApiException {
      return new AlipayClientComponent(aliPayProperties);
    }

    @Bean
    @ConditionalOnMissingBean
    public ApplicationContextHolder congoApplicationContextHolder() {
        return new ApplicationContextHolder();
    }

}
