package com.framework.pay.core.base;

import com.alipay.api.AlipayApiException;
import com.framework.pay.core.base.param.*;
import com.framework.pay.core.exception.PayServiceException;

/**
 * @Filename: PayService
 * @Author: zzy
 * @Data:2023/4/28 22:04
 * @Description: 统一支付抽象接口
 */
public interface PayService extends PayMarkService{

    /**
     * 抽象支付方法
     *
     * @param payParam  支付对象
     * @return          支付响应
     */
    AbstractResponseParam pay(AbstractPayParam payParam) throws PayServiceException, AlipayApiException;

    /**
     * 抽象支付查询方法
     *
     * @param queryParam 支付查询对象
     * @return           查询响应
     */
    AbstractResponseParam tradeQuery(AbstractQueryParam queryParam)throws PayServiceException;

    /**
     * 抽象退款方法
     *
     * @param refundParam 退款参数对象
     * @return             退款响应
     * @throws PayServiceException
     */
    AbstractResponseParam refund(AbstractRefundParam refundParam) throws PayServiceException;

    /**
     * 抽象支付回调方法
     *
     * @param abstractCallBackParam 支付回调参数
     */
    void callBack(AbstractCallBackParam abstractCallBackParam)throws PayServiceException;

}
