package com.framework.pay.core.enums;

import java.util.Objects;

/**
 * @Filename: AlipayErrorEnum
 * @Author: zzy
 * @Data:2023/4/29 1:32
 * @Description: 阿里支付响应错误码
 */
public enum AlipayRespCodeEnum {

    SUCCESS("10000", "接口调用成功"),
    SERVICE_UNAVALIABLE("20000", "服务不可用"),
    GRANT_NOENOGH("20001", "授权权限不足"),
    LACK_PARAM("40001", "缺少必选参数"),
    ILLEGAL_PARAM("40002", "非法的参数"),
    CONDITION_ERROR("40003", "Insufficient Conditions（条件异常）"),
    BUSINESS_FAILED("40004", "业务处理失败"),
    CALL_LIMITED("40005", "Call Limited（调用频次超限）"),
    PERMISSION_LACK("40006", "权限不足"),
    CODE_NOT_EXISTS("500", "返回的响应码不存在"),
    ;

    /**
     * 响应码
     */
    private String code;

    /**
     * 响应描述
     */
    private String message;

    AlipayRespCodeEnum(String code, String message) {
        this.code = code;
        this.message = message;
    }

    /**
     * 根据code返回阿里支付响应错误码枚举
     *
     * @param code
     * @return
     */
    public static AlipayRespCodeEnum getAlipayRespCodeEnum(String code){
        for (AlipayRespCodeEnum value : AlipayRespCodeEnum.values()) {
            if(Objects.equals(value.getCode(),code)){
                return value;
            }
        }
        return AlipayRespCodeEnum.CODE_NOT_EXISTS;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
}
