/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.framework.pay.core.handler.alipay.filter;

import com.framework.pay.core.base.param.AbstractPayParam;
import com.framework.pay.core.enums.ServiceExceptionEnum;
import com.framework.pay.core.exception.PayServiceException;
import com.framework.pay.core.handler.alipay.param.AlipayParam;
import com.framework.pay.core.handler.alipay.param.AlipayQueryParam;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Component;

import java.math.BigDecimal;

/**
 * @Filename: AlipayParamFilter
 * @Author: zzy
 * @Data:2023/4/29 14:55
 * @Description: 阿里支付请求入参校验
 */
@Component
public class AlipayParamFilter {

    public AlipayParam filter(AbstractPayParam payParam) {
        if (!AlipayParam.class.getClass().isAssignableFrom(payParam.getClass()) &&
                !(payParam.getClass().equals(AlipayParam.class))) {
            throw new PayServiceException(ServiceExceptionEnum.ALIPAY_PAY_PARAM_COVERT_ERROR);
        }
        AlipayParam alipayParam = (AlipayParam) payParam;
        if (StringUtils.isEmpty(alipayParam.getOutTraderNo())) {
            throw new PayServiceException(ServiceExceptionEnum.ALIPAY_PAY_PARAM_OUTRADENO_NOT_NULL);
        } else if (StringUtils.isEmpty(alipayParam.getSubject())) {
            throw new PayServiceException(ServiceExceptionEnum.ALIPAY_PAY_PARAM_SUBJECT_NOT_NULL);
        } else if (alipayParam.getPrice().compareTo(BigDecimal.ZERO) <= 0) {
            throw new PayServiceException(ServiceExceptionEnum.ALIPAY_PAY_PARAM_PRICE_ERROR);
        }
        return alipayParam;
    }
}
