/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.framework.pay.core.handler.alipay.filter;

import com.framework.pay.core.base.param.AbstractQueryParam;
import com.framework.pay.core.enums.ServiceExceptionEnum;
import com.framework.pay.core.exception.PayServiceException;
import com.framework.pay.core.handler.alipay.param.AlipayQueryParam;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Component;

import java.util.Objects;

/**
 * @Filename: AlipayQueryParamFilter
 * @Author: zzy
 * @Data:2023/4/29 1:08
 * @Description: 支付宝查询参数校验
 */
@Component
public class AlipayQueryParamFilter {

    public AlipayQueryParam filter(AbstractQueryParam param) {
        if (!AlipayQueryParam.class.getClass().isAssignableFrom(param.getClass()) &&
                !(param.getClass().equals(AlipayQueryParam.class))) {
            throw new PayServiceException(ServiceExceptionEnum.ALIPAY_QUERY_PARAM_COVERT_ERROR);
        }
        AlipayQueryParam queryParam = (AlipayQueryParam) param;
        if (StringUtils.isAllEmpty(queryParam.getTradeNo(), queryParam.getOutTradeNo())) {
            throw new PayServiceException(ServiceExceptionEnum.ALIPAY_QUERY_PARAM_NULL);
        }
        return queryParam;
    }

}
