/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.framework.pay.core.handler.alipay.filter;

import com.framework.pay.core.base.param.AbstractRefundParam;
import com.framework.pay.core.enums.ServiceExceptionEnum;
import com.framework.pay.core.exception.PayServiceException;
import com.framework.pay.core.handler.alipay.param.AlipayQueryParam;
import com.framework.pay.core.handler.alipay.param.AlipayRefundParam;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Component;

import java.math.BigDecimal;

/**
 * @Filename: AlipayRefundParamFilter
 * @Author: zzy
 * @Data:2023/4/29 17:19
 * @Description: 支付宝退款参数校验
 */
@Component
public class AlipayRefundParamFilter {


    public AlipayRefundParam filter(AbstractRefundParam param){
        if (!AlipayRefundParam.class.getClass().isAssignableFrom(param.getClass()) &&
                !(param.getClass().equals(AlipayRefundParam.class))) {
            throw new PayServiceException(ServiceExceptionEnum.ALIPAY_REFUND_PARAM_COVERT_ERROR);
        }
        AlipayRefundParam refundParam = (AlipayRefundParam) param;
        if (StringUtils.isAllEmpty(refundParam.getTradeNo(), refundParam.getOutTradeNo())) {
            throw new PayServiceException(ServiceExceptionEnum.ALIPAY_QUERY_PARAM_NULL);
        }
        if(refundParam.getRefundAmount().compareTo(BigDecimal.ZERO) <=0 ){
            throw new PayServiceException(ServiceExceptionEnum.ALIPAY_REFUND_PRICE_ERROR);
        }
        return refundParam;
    }
}
