/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.framework.pay.core.handler.wxpay.config;

import lombok.Data;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.context.annotation.Configuration;

/**
 * @Filename: WxPayProperties
 * @Author: zzy
 * @Data:2023/5/4 10:50
 * @Description: 微信支付配置类
 */
@Data
@Configuration
@ConfigurationProperties(prefix = WxPayProperties.PREFIX)
public class WxPayProperties {

    public static final String PREFIX = "pay.wxpay";

    /**
     * 应用ID
     */
    private String appId;

    /**
     * 商户号
     */
    private String mchId;

    /**
     * 商户api私钥文件路径
     */
    private String merchantPrivateKeyPath;

    /**
     * 商户api证书文件路径
     */
    private String merchantCertificatepath;

    /**
     * 商户API证书序列号
     */
    private String serialNo;

    /**
     * 商户APIV3密钥
     */
    private String apiV3key;

    /**
     * 网关地址
     */
    private String serverUrl;

    /**
     * 支付结果回调地址
     */
    private String notifyUrl;
}
