/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.framework.wxpay.client.core.config;

import com.framework.wxpay.client.core.constant.Constant;
import com.framework.wxpay.client.core.domain.*;

import java.io.InputStream;

/**
 * @author zzy
 * @date 2023/5/12-17:31
 */
public abstract class AbstractHttpClient implements HttpClient {

    protected Credential credential;

    protected Validator validator;

    public AbstractHttpClient(Credential credential, Validator validator) {
        this.credential = credential;
        this.validator = validator;
    }

    protected abstract OriginalResponse innerExecute(HttpRequest httpRequest);

    @Override
    public <T> HttpResponse<T> execute(HttpRequest request, Class<T> responseClass) {
        HttpRequest innerRequest =
                new HttpRequest.Builder()
                        .url(request.getUrl())
                        .httpMethod(request.getHttpMethod())
                        .headers(request.getHeaders())
                        .addHeader(Constant.AUTHORIZATION, getAuthorization(request))
                        //.addHeader(Constant.USER_AGENT, getUserAgent())
                        .body(request.getBody())
                        .build();
        OriginalResponse originalResponse = innerExecute(innerRequest);
        //validateResponse(originalResponse);
        //return assembleHttpResponse(originalResponse, responseClass);
        return null;
    }


    @Override
    public InputStream download(String url) {
        return null;
    }


    private String getAuthorization(HttpRequest request) {
        return credential.getAuthorization(request.getUri(), request.getHttpMethod().name(), getSignBody(request.getBody()));
    }

    private String getSignBody(RequestBody requestBody) {
        if (requestBody == null) {
            return "";
        }
        if (requestBody instanceof JsonRequestBody) {
            return ((JsonRequestBody) requestBody).getBody();
        }
        /*if (requestBody instanceof FileRequestBody) {
            return ((FileRequestBody) requestBody).getMeta();
        }*/
        throw new UnsupportedOperationException(
                String.format("Unsupported RequestBody Type[%s]", requestBody.getClass().getName()));
    }

    protected abstract String getHttpClientInfo();
}
