/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.framework.wxpay.client.core.config;

import java.security.PrivateKey;

/**
 * @author zzy
 * @date 2023/5/12-16:38
 * @Description RSA方式抽象实现
 */

public class AbstractRSAConfig implements Config{

    /**
     * 商户api证书序列号
     */
    protected String certificateSerialNumber;

    /**
     * 商户api证书私钥
     */
    protected PrivateKey privateKey;

    /**
     * 商户ID
     */
    protected String merchanId;


    public AbstractRSAConfig(String certificateSerialNumber, PrivateKey privateKey, String merchanId) {
        this.certificateSerialNumber = certificateSerialNumber;
        this.privateKey = privateKey;
        this.merchanId = merchanId;
    }

    @Override
    public Signer createSigner() {
        return new RSASigner(certificateSerialNumber,privateKey);
    }

    @Override
    public Credential createCredential() {
        return new WechatCredentital(merchanId,createSigner());
    }

    @Override
    public Validator createValidator() {
        return null;
    }
}
