/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.framework.wxpay.client.core.config;

import com.framework.wxpay.client.core.constant.Constant;
import com.framework.wxpay.client.core.toolkit.KeyPairUtil;

import java.security.KeyPair;
import java.security.PrivateKey;

/**
 * @author zzy
 * @date 2023/5/12-16:44
 */
public abstract class AbstractRSAConfigBuilder<T extends AbstractRSAConfigBuilder<T>> {

    /**
     * 商户ID
     */
    protected String merchanId;

    /**
     * 商户api证书路径
     */
    protected String merchantCertificatePath;

    /**
     * 商户api私钥路径
     */
    protected String merchantPrivateKeyPath;

    /**
     * 商户api证书序列号
     */
    protected String serialNo;

    /**
     * 商户api私钥
     */
    protected PrivateKey privateKey;

    /**
     * 返回自身对象
     *
     * @return
     */
    protected abstract T self();

    /**
     * 构建商户号
     *
     * @param merchanId
     * @return
     */
    public T merchanId(String merchanId) {
        this.merchanId = merchanId;
        return self();
    }

    /**
     * 构建商户序列号
     *
     * @param serialNo
     * @return
     */
    public T serialNo(String serialNo) {
        this.serialNo = serialNo;
        return self();
    }


    /**
     * 根据商户api证书加载私钥等信息
     *
     * @param merchantCertificatePath
     * @return
     */
    public T merchantCertificatePath(String merchantCertificatePath) {
        KeyPair keyPair = KeyPairUtil.getKeyPair(merchantPrivateKeyPath, Constant.KEYPASS, merchanId);
        privateKey = keyPair.getPrivate();
        return self();
    }

    /**
     * 设置商户api私钥
     *
     * @param privateKey
     * @return
     */
    public T privateKey(PrivateKey privateKey) {
        this.privateKey = privateKey;
        return self();
    }
}



