/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.framework.wxpay.client.core.config;

import java.net.URI;

/**
 * @author zzy
 * @date 2023/5/12-16:21
 * @Description 抽象微信支付认证信息方法，微信支付Authorization生成
 */

/**
 * 认证信息流程
 * <p>
 * 1、发起请求的商户（包括直连商户、服务商或渠道商）的商户号 mchid
 * 2、商户API证书序列号serial_no，用于声明所使用的证书
 * 3、请求随机串nonce_str
 * 4、时间戳timestamp
 * 5、签名值signature
 * <p>
 * 认证类型，目前为WECHATPAY2-SHA256-RSA2048
 */
public interface Credential {

    /**
     * 获取微信支付认证authorization
     *
     * @param uri         请求uri
     * @param httpMethod  请求方式 POST/GET/PUT....
     * @param signMessage 签名信息
     * @return
     */
    String getAuthorization(URI uri, String httpMethod, String signMessage);

    /**
     * 获取商户号
     *
     * @return 商户号
     */
    String getMerchantId();

    /**
     * 获取认证类型
     *
     * @return 认证类型
     */
    String getSchema();

}
