/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.framework.toolkit;

import org.springframework.util.StringUtils;

/**
 * @Filename:
 * @Author: zzy
 * @Date: 2023/6/5-10:48
 * @Description: 签名生成、校验、加解密抽象实现
 */
public abstract class BaseAsymmetricEncryptor implements IAsymmetricEncryptor {

    private static String DEFAULT_CHARSET = "utf-8";

    @Override
    public String sign(String sourceContent, String privatekey, String charset) throws Exception {
        if (StringUtils.isEmpty(sourceContent)) {
            throw new Exception("source content is empty");
        } else if (StringUtils.isEmpty(privatekey)) {
            throw new Exception("privatekey is empty");
        } else {
            if (StringUtils.isEmpty(charset)) {
                charset = DEFAULT_CHARSET;
            }
        }
        String signMessage = this.doSign(sourceContent, privatekey, charset);
        return signMessage;
    }

    @Override
    public boolean verify(String sourceContent, String publicKey, String charset, String sign) throws Exception {
        if(StringUtils.isEmpty(sourceContent)){
            throw new Exception("source content is empty");
        }else if(StringUtils.isEmpty(publicKey)){
            throw new Exception("privatekey is empty");
        } else if (StringUtils.isEmpty(sign)) {
            throw new Exception("sign is empty");
        }else if(StringUtils.isEmpty(charset)){
            charset = DEFAULT_CHARSET;
        }
        return this.doVerify(sourceContent,publicKey,charset,sign);
    }

    protected abstract String doSign(String sourceContent, String privateKey, String charset) throws Exception;

    protected abstract boolean doVerify(String sourceContent,String publicKey,String charset,String sign)throws Exception;
}
