/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.framework.toolkit;

import lombok.NoArgsConstructor;

import java.util.HashMap;
import java.util.Map;
import java.util.Optional;

/**
 * @Filename: EncryptManager
 * @Author: zzy
 * @Date: 2023/6/2-13:49
 * @Description:
 */
@NoArgsConstructor
public class EncryptManager {

    /**
     * 默认加解密对象集合
     */
    private static Map<String,Encrypt> encryptManager = new HashMap<>();

    /**
     * 加密content内容
     *
     * @param content
     * @param encryType
     * @param encryKey
     * @param charset
     * @return
     */
    public static String encryptContent(String content,String encryType,String encryKey,String charset) throws Exception {
        Encrypt encrypt = Optional.ofNullable(encryptManager.get(encryType)).orElseThrow(() -> new Exception("encrypt null"));
        return encrypt.encrypt(content,encryKey,charset);
    }

    /**
     * 解密content内容
     *
     * @param content
     * @param encryType
     * @param encryKey
     * @param charset
     * @return
     * @throws Exception
     */
    public static String decryptContent(String content,String encryType,String encryKey,String charset) throws Exception {
        Encrypt encrypt = Optional.ofNullable(encryptManager.get(encryType)).orElseThrow(() -> new Exception("encrypt null"));
        return encrypt.decrypt(content,encryKey,charset);
    }

    static {
        encryptManager.put("AES",new AesEncrypt());
    }
}

