package com.framework.toolkit;

/**
 * @Filename:
 * @Author: zzy
 * @Date: 2023/6/5-10:34
 * @Description: 签名生成、校验、加解密抽象接口
 */
public interface IAsymmetricEncryptor {

    /**
     * 生成签名
     *
     * @param sourceContent
     * @param privatekey
     * @param charset
     * @return
     */
    String sign(String sourceContent, String privatekey, String charset) throws Exception;


    /**
     * 签名校验
     *
     * @param sourceContent
     * @param publicKey
     * @param charset
     * @param sign
     * @return
     */
    boolean verify(String sourceContent, String publicKey, String charset, String sign) throws Exception;


    /**
     * 公钥加密方法
     *
     * @param plainText   明文
     * @param charset
     * @param publicKey
     * @return
     */
    String encrypt(String plainText, String charset, String publicKey);

    /**
     * 私钥解密方法
     *
     * @param cipherText  密文
     * @param charset
     * @param privateKey
     * @return
     */
    String decrypt(String cipherText, String charset, String privateKey);
}
