/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.framework.toolkit.reader;

import java.text.CharacterIterator;
import java.util.HashMap;
import java.util.Map;

/**
 * @Filename:
 * @Author: zzy
 * @Date: 2023/6/9-17:33
 * @Description:
 */

public abstract class JSONReader {

    /**
     * 字符迭代器
     */
    private CharacterIterator it;

    /**
     * 当前迭代字符
     */
    private char c;

    /**
     * 一个迭代结束生产的对象
     */
    private Object token;

    /**
     * 存储迭代过程中产生的字符串
     */
    private StringBuffer buf = new StringBuffer();

    /**
     * 迭代结束标记对象
     */
    private static final Object OBJECT_END = new Object();

    /**
     * 迭代数组标记对象
     */
    private static final Object ARRAY_END = new Object();

    /**
     * 迭代分隔符对象(,)
     */
    private static final Object COLON = new Object();

    /**
     * 迭代分隔符对象(:)
     */
    private static final Object COMMA = new Object();


    public JSONReader() {

    }

    /**
     * 迭代下一个字符
     */
    private char next(){
        this.c = it.next();
        return this.c;
    }

    /**
     * 跳过空行
     */
    private void skipWhiteSpace(){
        while(Character.isWhitespace(this.c)){
            next();
        }
    }

    /**
     * 读取字符
     *
     * @param ci         字符串迭代器对象
     * @param start     开始读取的位置
     * @return
     */
    public Object read(CharacterIterator ci,int start){
        this.it = ci;
        switch (start){
            //表示开始位置
            case 0:
                this.c = it.first();
                break;
            case 1:
                this.c = it.current();
                break;
            case 2:
                this.c = it.next();
        }
        return this.read();
    }

    public Object read(){
        //跳过空字符
        this.skipWhiteSpace();
        //定义临时变量存储 当前字符
        char ch = this.c;
        //遍历到下一个字符
        this.next();
        //判断当前ch 属于什么字符做出对应方法
        switch (ch){
            case '{':
                //表示json字符串开始部分
                token = this.object();
               break;
            case '"':
                //表示json 一个key开始或者结束
                token = this.string();
                break;

        }
        return null;
    }

    /**
     * 组装元素
     * @return
     */
    private Object object(){
        Map<Object,Object> ret = new HashMap<>();
        Object key = this.read();
        //
        while(this.token != OBJECT_END){
            this.read();
            if(this.token != OBJECT_END){
                ret.put(key,this.read());
                if (this.read() == COMMA) {
                    key = this.read();
                }
            }
        }
        return ret;
    }

    /**
     * 读取字符串
     *
     * @return
     */
    private Object string(){
        //重置buf
        this.buf.setLength(0);
        while(this.c!='"'){
            if(this.c  == '\\'){
                //格式字符 跳过
                this.next();
               //todo
            }else{
                this.add();
            }
        }
        return buf.toString();
    }

    /**
     * 向临时缓存对象存储字符串
     */
    private void add(){
        this.buf.append(this.c);
        this.next();
    }
}

