package com.framework.junit.http.okhttp;

import java.security.PrivateKey;
import java.security.PublicKey;

/** RSAConfigBuilder抽象类 */
public abstract class AbstractRSAConfigBuilder<T extends AbstractRSAConfigBuilder<T>> {

  protected String merchantId;
  protected PrivateKey privateKey;
  protected String merchantSerialNumber;
  protected PublicKey publicKey;

  protected abstract T self();

  public T merchantId(String merchantId) {
    this.merchantId = merchantId;
    return self();
  }

  public T privateKey(String privateKey) {
    this.privateKey = PemUtil.loadPrivateKeyFromString(privateKey);
    return self();
  }

  public T privateKey(PrivateKey privateKey) {
    this.privateKey = privateKey;
    return self();
  }

  public T privateKeyFromPath(String keyPath) {
    this.privateKey = PemUtil.loadPrivateKeyFromPath(keyPath);
    return self();
  }

  public T privateKeyFromPath(PrivateKey keyPath) {
    this.privateKey = keyPath;
    return self();
  }

  public T merchantSerialNumber(String merchantSerialNumber) {
    this.merchantSerialNumber = merchantSerialNumber;
    return self();
  }
}
