package com.framework.junit.http.okhttp;


import org.springframework.core.io.ClassPathResource;
import org.springframework.core.io.Resource;

import java.io.IOException;
import java.io.InputStream;
import java.io.UncheckedIOException;
import java.security.KeyPair;
import java.security.KeyStore;
import java.security.PrivateKey;
import java.security.PublicKey;
import java.security.cert.X509Certificate;

/** H5Service使用示例 */
public class H5ServiceExample {

  private static KeyStore store;

  private final static Object lock = new Object();

  public static String merchantId = "1512186831";
  public static String privateKeyPath = "";
  public static String merchantSerialNumber = "639A85CC5198322F96B2E1DA09C6A12077BABA75";
  public static String wechatPayCertificatePath = "D:\\xwProject\\package\\wechatpay_4D86002A7500D0E15BFDFBC644CBD7E848FE74A4.pems";
  public static H5Service service;



    public static final String MERCHANT_PRIVATE_KEY_PATH;
    public static final String MERCHANT_CERTIFICATE_PATH;
    public static final String MERCHANT_PRIVATE_KEY_STRING;
    public static final String MERCHANT_CERTIFICATE_STRING;
    public static final String WECHAT_PAY_CERTIFICATE_PATH;
    public static final String WECHAT_PAY_CERTIFICATE_STRING;
    public static final String MERCHANT_CERTIFICATE_SERIAL_NUMBER =
            "54E7F59ED8DF4570CFB14780EA8152D45A675EE6";
    public static final String MERCHANT_ID = "1234567891";
    public static final String API_V3_KEY = "a7cde1ZJB1kG2e7VfTs3jQzaWizur8Gb";


    static {
        try {
            final String resourceDir =
                    System.getProperty("user.dir") + "/junit/src/main/resources/";
            MERCHANT_PRIVATE_KEY_PATH = resourceDir + "merchant_private_key.pem";
            MERCHANT_CERTIFICATE_PATH = resourceDir + "merchant_certificate.pem";
            WECHAT_PAY_CERTIFICATE_PATH = resourceDir + "wechat_pay_certificate.pem";
            MERCHANT_PRIVATE_KEY_STRING = IOUtil.loadStringFromPath(MERCHANT_PRIVATE_KEY_PATH);
            MERCHANT_CERTIFICATE_STRING = IOUtil.loadStringFromPath(MERCHANT_CERTIFICATE_PATH);
            WECHAT_PAY_CERTIFICATE_STRING = IOUtil.loadStringFromPath(WECHAT_PAY_CERTIFICATE_PATH);
        } catch (IOException e) {
            throw new UncheckedIOException(e);
        }
    }

  public static void main(String[] args) {
      KeyPair tenpay_certificate = createPKCS12("apiclient_uk_cert.p12", "Tenpay Certificate", "1512186831");




      // 初始化商户配置
      RSAConfig config =
              new RSAConfig.Builder()
                      .merchantId(MERCHANT_ID)
                      // 使用 com.wechat.pay.java.core.util 中的函数从本地文件中加载商户私钥，商户私钥会用来生成请求的签名
                      .privateKeyFromPath(MERCHANT_PRIVATE_KEY_PATH)
                      .merchantSerialNumber(MERCHANT_CERTIFICATE_SERIAL_NUMBER)
                      .wechatPayCertificatesFromPath(MERCHANT_CERTIFICATE_PATH)
                      .build();



    // 初始化服务
    service = new H5Service.Builder().config(config).build();
      prepay();
    // ... 调用接口
    try {
      //closeOrder();
    } catch (HttpException e) { // 发送HTTP请求失败
      // 调用e.getHttpRequest()获取请求打印日志或上报监控，更多方法见HttpException定义
    } catch (ServiceException e) { // 服务返回状态小于200或大于等于300，例如500
      // 调用e.getResponseBody()获取返回体打印日志或上报监控，更多方法见ServiceException定义
    } catch (MalformedMessageException e) { // 服务返回成功，返回体类型不合法，或者解析返回体失败
      // 调用e.getMessage()获取信息打印日志或上报监控，更多方法见MalformedMessageException定义
    }

  }

  /** H5支付下单 */
  public static PrepayResponse prepay() {
    PrepayRequest request = new PrepayRequest();
    // 调用request.setXxx(val)设置所需参数，具体参数可见Request定义
    // 调用接口

    request.setAppid("wxd8bf812eebe3f58b");
    Amount amount = new Amount();
    amount.setCurrency("CNY");
    amount.setTotal(1);
    request.setAmount(amount);
    request.setDescription("测试");
    request.setMchid("1512186831");
    request.setOutTradeNo("1111111111111111");
    request.setNotifyUrl("https://www.xwsoft.com.cn/freesim/wxH5/wxH5PayNotify");
    SceneInfo sceneInfo = new SceneInfo();
    sceneInfo.setPayerClientIp("127.0.0.1");

    request.setSceneInfo(sceneInfo);
    PrepayResponse prepay = service.prepay(request);
    System.out.println(prepay);
    return prepay;
  }


  /**
   * 获取公私钥.
   *
   * @param keyPath  the key path
   * @param keyAlias the key alias
   * @param keyPass  password
   * @return the key pair
   */
  public static KeyPair createPKCS12(String keyPath, String keyAlias, String keyPass) {
    char[] pem = keyPass.toCharArray();
    try {
      synchronized (lock) {
        if (store == null) {
          synchronized (lock) {
            Resource resource = new ClassPathResource(keyPath);
            InputStream in = resource.getInputStream();
            store = KeyStore.getInstance("PKCS12");
            store.load(in, pem);
          }
        }
      }
      X509Certificate certificate = (X509Certificate) store.getCertificate(keyAlias);
      certificate.checkValidity();
      // 证书的序列号 也有用
      String serialNumber = certificate.getSerialNumber().toString(16).toUpperCase();
      // 证书的 公钥
      PublicKey publicKey = certificate.getPublicKey();
      // 证书的私钥
      PrivateKey storeKey = (PrivateKey) store.getKey(keyAlias, pem);

      return new KeyPair(publicKey, storeKey);

    } catch (Exception e) {
      throw new IllegalStateException("Cannot load keys from store: " , e);
    }
  }


}
