package com.framework.junit.http.okhttp;

import java.security.PrivateKey;
import java.security.PublicKey;
import java.security.cert.X509Certificate;
import java.util.ArrayList;
import java.util.List;

import static java.util.Objects.requireNonNull;

/** 调用微信支付服务需要的RSA相关配置 */
public final class RSAConfig extends AbstractRSAConfig {

  private RSAConfig(
          String merchantId,
          PrivateKey privateKey,
          String merchantSerialNumber,
          CertificateProvider certificateProvider,
          PublicKey publicKey) {
    super(merchantId, privateKey, merchantSerialNumber, certificateProvider,publicKey);
  }

  public static class Builder extends AbstractRSAConfigBuilder<Builder> {

    private List<X509Certificate> wechatPayCertificates;

    @Override
    protected Builder self() {
      return this;
    }

    public Builder wechatPayCertificates(String... wechatPayCertificates) {
      this.wechatPayCertificates = new ArrayList<>();
      for (String certificate : wechatPayCertificates) {
        X509Certificate x509Certificate = PemUtil.loadX509FromString(certificate);
        if (x509Certificate != null) {
          this.wechatPayCertificates.add(x509Certificate);
        }
      }
      return this;
    }

        public Builder wechatPayCertificatesFromPath(String... certPaths) {
          try{
            this.wechatPayCertificates = new ArrayList<>();
            for (String certPath : certPaths) {
              X509Certificate x509Certificate = PemUtil.loadX509FromPath(certPath);
              if (x509Certificate != null) {
                this.wechatPayCertificates.add(x509Certificate);
              }
            }
          }catch (Exception e){

          }

          return this;
        }


    public Builder publicKey(PublicKey publicKey) {
      this.publicKey = publicKey;
      return this;
    }

    public RSAConfig build() {
      return new RSAConfig(
          requireNonNull(merchantId),
          requireNonNull(privateKey),
          requireNonNull(merchantSerialNumber),
          new InMemoryCertificateProvider(requireNonNull(wechatPayCertificates)),
              requireNonNull(publicKey));
    }
  }
}
